@@ -7,7 +7,7 @@ from typing import List, Tuple
 import os
 import sys
 
-from chia.util.db_wrapper import DBWrapper
+from chia.util.db_wrapper import DBWrapper2
 from chia.types.blockchain_format.sized_bytes import bytes32
 from chia.types.blockchain_format.coin import Coin
 from chia.util.ints import uint64, uint32
@@ -37,7 +37,7 @@ def make_coins(num: int) -> Tuple[List[Coin], List[bytes32]]:
 async def run_new_block_benchmark(version: int):
 
     verbose: bool = "--verbose" in sys.argv
-    db_wrapper: DBWrapper = await setup_db("coin-store-benchmark.db", version)
+    db_wrapper: DBWrapper2 = await setup_db("coin-store-benchmark.db", version)
 
     # keep track of benchmark total time
     all_test_time = 0.0
@@ -75,7 +75,6 @@ async def run_new_block_benchmark(version: int):
                 additions,
                 removals,
             )
-            await db_wrapper.db.commit()
 
             # 19 seconds per block
             timestamp += 19
@@ -117,7 +116,6 @@ async def run_new_block_benchmark(version: int):
                 additions,
                 removals,
             )
-            await db_wrapper.db.commit()
             stop = monotonic()
 
             # 19 seconds per block
@@ -168,7 +166,6 @@ async def run_new_block_benchmark(version: int):
                 additions,
                 removals,
             )
-            await db_wrapper.db.commit()
 
             stop = monotonic()
 
@@ -218,7 +215,6 @@ async def run_new_block_benchmark(version: int):
                 additions,
                 removals,
             )
-            await db_wrapper.db.commit()
             stop = monotonic()
 
             # 19 seconds per block
@@ -305,7 +301,7 @@ async def run_new_block_benchmark(version: int):
         print(f"all tests completed in {all_test_time:0.4f}s")
 
     finally:
-        await db_wrapper.db.close()
+        await db_wrapper.close()
 
     db_size = os.path.getsize(Path("coin-store-benchmark.db"))
     print(f"database size: {db_size/1000000:.3f} MB")
