@@ -5,6 +5,8 @@ from pathlib import Path
 
 import click
 
+from chia.plotting.util import add_plot_directory, validate_plot_size
+
 DEFAULT_STRIPE_SIZE = 65536
 log = logging.getLogger(__name__)
 
@@ -128,29 +130,29 @@ def create_cmd(
             self.plotid = plotid
             self.memo = memo
             self.nobitfield = nobitfield
-            self.exclude_final_dir = exclude_final_dir
 
-    if size < 32 and not override_k:
-        print("k=32 is the minimum size for farming.")
-        print("If you are testing and you want to use smaller size please add the --override-k flag.")
-        sys.exit(1)
-    elif size < 25 and override_k:
-        print("Error: The minimum k size allowed from the cli is k=25.")
+    root_path: Path = ctx.obj["root_path"]
+    try:
+        validate_plot_size(root_path, size, override_k)
+    except ValueError as e:
+        print(e)
         sys.exit(1)
 
-    plot_keys = asyncio.get_event_loop().run_until_complete(
+    plot_keys = asyncio.run(
         resolve_plot_keys(
             farmer_public_key,
             alt_fingerprint,
             pool_public_key,
             pool_contract_address,
-            ctx.obj["root_path"],
+            root_path,
             log,
             connect_to_daemon,
         )
     )
 
-    asyncio.get_event_loop().run_until_complete(create_plots(Params(), plot_keys, ctx.obj["root_path"]))
+    asyncio.run(create_plots(Params(), plot_keys))
+    if not exclude_final_dir:
+        add_plot_directory(root_path, final_dir)
 
 
 @plots_cmd.command("check", short_help="Checks plots")
