@@ -11,7 +11,13 @@ from chia.consensus.network_type import NetworkType
 from chia.consensus.pot_iterations import calculate_iterations_quality, calculate_sp_interval_iters
 from chia.farmer.farmer import Farmer
 from chia.protocols import farmer_protocol, harvester_protocol
-from chia.protocols.harvester_protocol import PoolDifficulty
+from chia.protocols.harvester_protocol import (
+    PoolDifficulty,
+    PlotSyncStart,
+    PlotSyncPlotList,
+    PlotSyncPathList,
+    PlotSyncDone,
+)
 from chia.protocols.pool_protocol import (
     get_current_authentication_token,
     PoolErrorCode,
@@ -518,3 +524,38 @@ class FarmerAPI:
     @peer_required
     async def respond_plots(self, _: harvester_protocol.RespondPlots, peer: ws.WSChiaConnection):
         self.farmer.log.warning(f"Respond plots came too late from: {peer.get_peer_logging()}")
+
+    @api_request
+    @peer_required
+    async def plot_sync_start(self, message: PlotSyncStart, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].sync_started(message)
+
+    @api_request
+    @peer_required
+    async def plot_sync_loaded(self, message: PlotSyncPlotList, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].process_loaded(message)
+
+    @api_request
+    @peer_required
+    async def plot_sync_removed(self, message: PlotSyncPathList, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].process_removed(message)
+
+    @api_request
+    @peer_required
+    async def plot_sync_invalid(self, message: PlotSyncPathList, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].process_invalid(message)
+
+    @api_request
+    @peer_required
+    async def plot_sync_keys_missing(self, message: PlotSyncPathList, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].process_keys_missing(message)
+
+    @api_request
+    @peer_required
+    async def plot_sync_duplicates(self, message: PlotSyncPathList, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].process_duplicates(message)
+
+    @api_request
+    @peer_required
+    async def plot_sync_done(self, message: PlotSyncDone, peer: ws.WSChiaConnection):
+        await self.farmer.plot_sync_receivers[peer.peer_node_id].sync_done(message)
