@@ -1,10 +1,12 @@
 from typing import List, Optional, Set, Dict, Any, Tuple
-import aiosqlite
+
+from aiosqlite import Cursor
+
 from chia.protocols.wallet_protocol import CoinState
 from chia.types.blockchain_format.coin import Coin
 from chia.types.blockchain_format.sized_bytes import bytes32
 from chia.types.coin_record import CoinRecord
-from chia.util.db_wrapper import DBWrapper
+from chia.util.db_wrapper import DBWrapper2
 from chia.util.ints import uint32, uint64
 from chia.util.lru_cache import LRUCache
 from chia.util.chunks import chunks
@@ -22,74 +24,72 @@ class CoinStore:
     A cache is maintained for quicker access to recent coins.
     """
 
-    coin_record_db: aiosqlite.Connection
     coin_record_cache: LRUCache
     cache_size: uint32
-    db_wrapper: DBWrapper
+    db_wrapper: DBWrapper2
 
     @classmethod
-    async def create(cls, db_wrapper: DBWrapper, cache_size: uint32 = uint32(60000)):
+    async def create(cls, db_wrapper: DBWrapper2, cache_size: uint32 = uint32(60000)):
         self = cls()
 
         self.cache_size = cache_size
         self.db_wrapper = db_wrapper
-        self.coin_record_db = db_wrapper.db
 
-        if self.db_wrapper.db_version == 2:
+        async with self.db_wrapper.write_db() as conn:
 
-            # the coin_name is unique in this table because the CoinStore always
-            # only represent a single peak
-            await self.coin_record_db.execute(
-                "CREATE TABLE IF NOT EXISTS coin_record("
-                "coin_name blob PRIMARY KEY,"
-                " confirmed_index bigint,"
-                " spent_index bigint,"  # if this is zero, it means the coin has not been spent
-                " coinbase int,"
-                " puzzle_hash blob,"
-                " coin_parent blob,"
-                " amount blob,"  # we use a blob of 8 bytes to store uint64
-                " timestamp bigint)"
-            )
+            if self.db_wrapper.db_version == 2:
 
-        else:
-
-            # the coin_name is unique in this table because the CoinStore always
-            # only represent a single peak
-            await self.coin_record_db.execute(
-                (
+                # the coin_name is unique in this table because the CoinStore always
+                # only represent a single peak
+                await conn.execute(
                     "CREATE TABLE IF NOT EXISTS coin_record("
-                    "coin_name text PRIMARY KEY,"
+                    "coin_name blob PRIMARY KEY,"
                     " confirmed_index bigint,"
-                    " spent_index bigint,"
-                    " spent int,"
+                    " spent_index bigint,"  # if this is zero, it means the coin has not been spent
                     " coinbase int,"
-                    " puzzle_hash text,"
-                    " coin_parent text,"
-                    " amount blob,"
+                    " puzzle_hash blob,"
+                    " coin_parent blob,"
+                    " amount blob,"  # we use a blob of 8 bytes to store uint64
                     " timestamp bigint)"
                 )
-            )
 
-        # Useful for reorg lookups
-        await self.coin_record_db.execute(
-            "CREATE INDEX IF NOT EXISTS coin_confirmed_index on coin_record(confirmed_index)"
-        )
+            else:
 
-        await self.coin_record_db.execute("CREATE INDEX IF NOT EXISTS coin_spent_index on coin_record(spent_index)")
+                # the coin_name is unique in this table because the CoinStore always
+                # only represent a single peak
+                await conn.execute(
+                    (
+                        "CREATE TABLE IF NOT EXISTS coin_record("
+                        "coin_name text PRIMARY KEY,"
+                        " confirmed_index bigint,"
+                        " spent_index bigint,"
+                        " spent int,"
+                        " coinbase int,"
+                        " puzzle_hash text,"
+                        " coin_parent text,"
+                        " amount blob,"
+                        " timestamp bigint)"
+                    )
+                )
 
-        await self.coin_record_db.execute("CREATE INDEX IF NOT EXISTS coin_puzzle_hash on coin_record(puzzle_hash)")
+            # Useful for reorg lookups
+            await conn.execute("CREATE INDEX IF NOT EXISTS coin_confirmed_index on coin_record(confirmed_index)")
 
-        await self.coin_record_db.execute("CREATE INDEX IF NOT EXISTS coin_parent_index on coin_record(coin_parent)")
+            await conn.execute("CREATE INDEX IF NOT EXISTS coin_spent_index on coin_record(spent_index)")
+
+            await conn.execute("CREATE INDEX IF NOT EXISTS coin_puzzle_hash on coin_record(puzzle_hash)")
+
+            await conn.execute("CREATE INDEX IF NOT EXISTS coin_parent_index on coin_record(coin_parent)")
 
-        await self.coin_record_db.commit()
         self.coin_record_cache = LRUCache(cache_size)
         return self
 
     async def num_unspent(self) -> int:
-        async with self.coin_record_db.execute("SELECT COUNT(*) FROM coin_record WHERE spent_index=0") as cursor:
-            row = await cursor.fetchone()
-            if row is not None:
-                return row[0]
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute("SELECT COUNT(*) FROM coin_record WHERE spent_index=0") as cursor:
+                row = await cursor.fetchone()
+        if row is not None:
+            return row[0]
         return 0
 
     def maybe_from_hex(self, field: Any) -> bytes:
@@ -165,48 +165,51 @@ class CoinStore:
         if cached is not None:
             return cached
 
-        async with self.coin_record_db.execute(
-            "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            "coin_parent, amount, timestamp FROM coin_record WHERE coin_name=?",
-            (self.maybe_to_hex(coin_name),),
-        ) as cursor:
-            row = await cursor.fetchone()
-            if row is not None:
-                coin = self.row_to_coin(row)
-                record = CoinRecord(coin, row[0], row[1], row[2], row[6])
-                self.coin_record_cache.put(record.coin.name(), record)
-                return record
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute(
+                "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                "coin_parent, amount, timestamp FROM coin_record WHERE coin_name=?",
+                (self.maybe_to_hex(coin_name),),
+            ) as cursor:
+                row = await cursor.fetchone()
+                if row is not None:
+                    coin = self.row_to_coin(row)
+                    record = CoinRecord(coin, row[0], row[1], row[2], row[6])
+                    self.coin_record_cache.put(record.coin.name(), record)
+                    return record
         return None
 
     async def get_coins_added_at_height(self, height: uint32) -> List[CoinRecord]:
-        async with self.coin_record_db.execute(
-            "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            "coin_parent, amount, timestamp FROM coin_record WHERE confirmed_index=?",
-            (height,),
-        ) as cursor:
-            rows = await cursor.fetchall()
-            coins = []
-            for row in rows:
-                coin = self.row_to_coin(row)
-                coins.append(CoinRecord(coin, row[0], row[1], row[2], row[6]))
-            return coins
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute(
+                "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                "coin_parent, amount, timestamp FROM coin_record WHERE confirmed_index=?",
+                (height,),
+            ) as cursor:
+                rows = await cursor.fetchall()
+                coins = []
+                for row in rows:
+                    coin = self.row_to_coin(row)
+                    coins.append(CoinRecord(coin, row[0], row[1], row[2], row[6]))
+                return coins
 
     async def get_coins_removed_at_height(self, height: uint32) -> List[CoinRecord]:
         # Special case to avoid querying all unspent coins (spent_index=0)
         if height == 0:
             return []
-        async with self.coin_record_db.execute(
-            "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            "coin_parent, amount, timestamp FROM coin_record WHERE spent_index=?",
-            (height,),
-        ) as cursor:
-            coins = []
-            for row in await cursor.fetchall():
-                if row[1] != 0:
-                    coin = self.row_to_coin(row)
-                    coin_record = CoinRecord(coin, row[0], row[1], row[2], row[6])
-                    coins.append(coin_record)
-            return coins
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute(
+                "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                "coin_parent, amount, timestamp FROM coin_record WHERE spent_index=?",
+                (height,),
+            ) as cursor:
+                coins = []
+                for row in await cursor.fetchall():
+                    if row[1] != 0:
+                        coin = self.row_to_coin(row)
+                        coin_record = CoinRecord(coin, row[0], row[1], row[2], row[6])
+                        coins.append(coin_record)
+                return coins
 
     # Checks DB and DiffStores for CoinRecords with puzzle_hash and returns them
     async def get_coin_records_by_puzzle_hash(
@@ -219,18 +222,19 @@ class CoinStore:
 
         coins = set()
 
-        async with self.coin_record_db.execute(
-            f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash WHERE puzzle_hash=? "
-            f"AND confirmed_index>=? AND confirmed_index<? "
-            f"{'' if include_spent_coins else 'AND spent_index=0'}",
-            (self.maybe_to_hex(puzzle_hash), start_height, end_height),
-        ) as cursor:
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute(
+                f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash WHERE puzzle_hash=? "
+                f"AND confirmed_index>=? AND confirmed_index<? "
+                f"{'' if include_spent_coins else 'AND spent_index=0'}",
+                (self.maybe_to_hex(puzzle_hash), start_height, end_height),
+            ) as cursor:
 
-            for row in await cursor.fetchall():
-                coin = self.row_to_coin(row)
-                coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
-            return list(coins)
+                for row in await cursor.fetchall():
+                    coin = self.row_to_coin(row)
+                    coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
+                return list(coins)
 
     async def get_coin_records_by_puzzle_hashes(
         self,
@@ -248,19 +252,21 @@ class CoinStore:
             puzzle_hashes_db = tuple(puzzle_hashes)
         else:
             puzzle_hashes_db = tuple([ph.hex() for ph in puzzle_hashes])
-        async with self.coin_record_db.execute(
-            f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash "
-            f'WHERE puzzle_hash in ({"?," * (len(puzzle_hashes) - 1)}?) '
-            f"AND confirmed_index>=? AND confirmed_index<? "
-            f"{'' if include_spent_coins else 'AND spent_index=0'}",
-            puzzle_hashes_db + (start_height, end_height),
-        ) as cursor:
 
-            for row in await cursor.fetchall():
-                coin = self.row_to_coin(row)
-                coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
-            return list(coins)
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute(
+                f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash "
+                f'WHERE puzzle_hash in ({"?," * (len(puzzle_hashes) - 1)}?) '
+                f"AND confirmed_index>=? AND confirmed_index<? "
+                f"{'' if include_spent_coins else 'AND spent_index=0'}",
+                puzzle_hashes_db + (start_height, end_height),
+            ) as cursor:
+
+                for row in await cursor.fetchall():
+                    coin = self.row_to_coin(row)
+                    coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
+                return list(coins)
 
     async def get_coin_records_by_names(
         self,
@@ -278,17 +284,20 @@ class CoinStore:
             names_db = tuple(names)
         else:
             names_db = tuple([name.hex() for name in names])
-        async with self.coin_record_db.execute(
-            f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            f'coin_parent, amount, timestamp FROM coin_record WHERE coin_name in ({"?," * (len(names) - 1)}?) '
-            f"AND confirmed_index>=? AND confirmed_index<? "
-            f"{'' if include_spent_coins else 'AND spent_index=0'}",
-            names_db + (start_height, end_height),
-        ) as cursor:
 
-            for row in await cursor.fetchall():
-                coin = self.row_to_coin(row)
-                coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
+        async with self.db_wrapper.read_db() as conn:
+            async with conn.execute(
+                f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                f"coin_parent, amount, timestamp FROM coin_record INDEXED BY sqlite_autoindex_coin_record_1 "
+                f'WHERE coin_name in ({"?," * (len(names) - 1)}?) '
+                f"AND confirmed_index>=? AND confirmed_index<? "
+                f"{'' if include_spent_coins else 'AND spent_index=0'}",
+                names_db + (start_height, end_height),
+            ) as cursor:
+
+                for row in await cursor.fetchall():
+                    coin = self.row_to_coin(row)
+                    coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
 
         return list(coins)
 
@@ -314,23 +323,24 @@ class CoinStore:
             return []
 
         coins = set()
-        for puzzles in chunks(puzzle_hashes, MAX_SQLITE_PARAMETERS):
-            puzzle_hashes_db: Tuple[Any, ...]
-            if self.db_wrapper.db_version == 2:
-                puzzle_hashes_db = tuple(puzzles)
-            else:
-                puzzle_hashes_db = tuple([ph.hex() for ph in puzzles])
-            async with self.coin_record_db.execute(
-                f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-                f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash "
-                f'WHERE puzzle_hash in ({"?," * (len(puzzles) - 1)}?) '
-                f"AND (confirmed_index>=? OR spent_index>=?)"
-                f"{'' if include_spent_coins else 'AND spent_index=0'}",
-                puzzle_hashes_db + (min_height, min_height),
-            ) as cursor:
+        async with self.db_wrapper.read_db() as conn:
+            for puzzles in chunks(puzzle_hashes, MAX_SQLITE_PARAMETERS):
+                puzzle_hashes_db: Tuple[Any, ...]
+                if self.db_wrapper.db_version == 2:
+                    puzzle_hashes_db = tuple(puzzles)
+                else:
+                    puzzle_hashes_db = tuple([ph.hex() for ph in puzzles])
+                async with conn.execute(
+                    f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                    f"coin_parent, amount, timestamp FROM coin_record INDEXED BY coin_puzzle_hash "
+                    f'WHERE puzzle_hash in ({"?," * (len(puzzles) - 1)}?) '
+                    f"AND (confirmed_index>=? OR spent_index>=?)"
+                    f"{'' if include_spent_coins else 'AND spent_index=0'}",
+                    puzzle_hashes_db + (min_height, min_height),
+                ) as cursor:
 
-                async for row in cursor:
-                    coins.add(self.row_to_coin_state(row))
+                    async for row in cursor:
+                        coins.add(self.row_to_coin_state(row))
 
         return list(coins)
 
@@ -345,23 +355,25 @@ class CoinStore:
             return []
 
         coins = set()
-        for ids in chunks(parent_ids, MAX_SQLITE_PARAMETERS):
-            parent_ids_db: Tuple[Any, ...]
-            if self.db_wrapper.db_version == 2:
-                parent_ids_db = tuple(ids)
-            else:
-                parent_ids_db = tuple([pid.hex() for pid in ids])
-            async with self.coin_record_db.execute(
-                f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-                f'coin_parent, amount, timestamp FROM coin_record WHERE coin_parent in ({"?," * (len(ids) - 1)}?) '
-                f"AND confirmed_index>=? AND confirmed_index<? "
-                f"{'' if include_spent_coins else 'AND spent_index=0'}",
-                parent_ids_db + (start_height, end_height),
-            ) as cursor:
+        async with self.db_wrapper.read_db() as conn:
+            for ids in chunks(parent_ids, MAX_SQLITE_PARAMETERS):
+                parent_ids_db: Tuple[Any, ...]
+                if self.db_wrapper.db_version == 2:
+                    parent_ids_db = tuple(ids)
+                else:
+                    parent_ids_db = tuple([pid.hex() for pid in ids])
+                async with conn.execute(
+                    f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                    f'coin_parent, amount, timestamp FROM coin_record WHERE coin_parent in ({"?," * (len(ids) - 1)}?) '
+                    f"AND confirmed_index>=? AND confirmed_index<? "
+                    f"{'' if include_spent_coins else 'AND spent_index=0'}",
+                    parent_ids_db + (start_height, end_height),
+                ) as cursor:
+
+                    async for row in cursor:
+                        coin = self.row_to_coin(row)
+                        coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
 
-                async for row in cursor:
-                    coin = self.row_to_coin(row)
-                    coins.add(CoinRecord(coin, row[0], row[1], row[2], row[6]))
         return list(coins)
 
     async def get_coin_states_by_ids(
@@ -374,21 +386,22 @@ class CoinStore:
             return []
 
         coins = set()
-        for ids in chunks(coin_ids, MAX_SQLITE_PARAMETERS):
-            coin_ids_db: Tuple[Any, ...]
-            if self.db_wrapper.db_version == 2:
-                coin_ids_db = tuple(ids)
-            else:
-                coin_ids_db = tuple([pid.hex() for pid in ids])
-            async with self.coin_record_db.execute(
-                f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-                f'coin_parent, amount, timestamp FROM coin_record WHERE coin_name in ({"?," * (len(ids) - 1)}?) '
-                f"AND (confirmed_index>=? OR spent_index>=?)"
-                f"{'' if include_spent_coins else 'AND spent_index=0'}",
-                coin_ids_db + (min_height, min_height),
-            ) as cursor:
-                async for row in cursor:
-                    coins.add(self.row_to_coin_state(row))
+        async with self.db_wrapper.read_db() as conn:
+            for ids in chunks(coin_ids, MAX_SQLITE_PARAMETERS):
+                coin_ids_db: Tuple[Any, ...]
+                if self.db_wrapper.db_version == 2:
+                    coin_ids_db = tuple(ids)
+                else:
+                    coin_ids_db = tuple([pid.hex() for pid in ids])
+                async with conn.execute(
+                    f"SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                    f'coin_parent, amount, timestamp FROM coin_record WHERE coin_name in ({"?," * (len(ids) - 1)}?) '
+                    f"AND (confirmed_index>=? OR spent_index>=?)"
+                    f"{'' if include_spent_coins else 'AND spent_index=0'}",
+                    coin_ids_db + (min_height, min_height),
+                ) as cursor:
+                    async for row in cursor:
+                        coins.add(self.row_to_coin_state(row))
         return list(coins)
 
     async def rollback_to_block(self, block_index: int) -> List[CoinRecord]:
@@ -415,38 +428,37 @@ class CoinStore:
             self.coin_record_cache.remove(coin_name)
 
         coin_changes: Dict[bytes32, CoinRecord] = {}
-        async with self.coin_record_db.execute(
-            "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            "coin_parent, amount, timestamp FROM coin_record WHERE confirmed_index>?",
-            (block_index,),
-        ) as cursor:
-            for row in await cursor.fetchall():
-                coin = self.row_to_coin(row)
-                record = CoinRecord(coin, uint32(0), row[1], row[2], uint64(0))
-                coin_changes[record.name] = record
-
-        # Delete from storage
-        await self.coin_record_db.execute("DELETE FROM coin_record WHERE confirmed_index>?", (block_index,))
-
-        async with self.coin_record_db.execute(
-            "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
-            "coin_parent, amount, timestamp FROM coin_record WHERE confirmed_index>?",
-            (block_index,),
-        ) as cursor:
-            for row in await cursor.fetchall():
-                coin = self.row_to_coin(row)
-                record = CoinRecord(coin, row[0], uint32(0), row[2], row[6])
-                if record.name not in coin_changes:
+        async with self.db_wrapper.write_db() as conn:
+            async with conn.execute(
+                "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                "coin_parent, amount, timestamp FROM coin_record WHERE confirmed_index>?",
+                (block_index,),
+            ) as cursor:
+                for row in await cursor.fetchall():
+                    coin = self.row_to_coin(row)
+                    record = CoinRecord(coin, uint32(0), row[1], row[2], uint64(0))
                     coin_changes[record.name] = record
 
-        if self.db_wrapper.db_version == 2:
-            await self.coin_record_db.execute(
-                "UPDATE coin_record SET spent_index=0 WHERE spent_index>?", (block_index,)
-            )
-        else:
-            await self.coin_record_db.execute(
-                "UPDATE coin_record SET spent_index = 0, spent = 0 WHERE spent_index>?", (block_index,)
-            )
+            # Delete from storage
+            await conn.execute("DELETE FROM coin_record WHERE confirmed_index>?", (block_index,))
+
+            async with conn.execute(
+                "SELECT confirmed_index, spent_index, coinbase, puzzle_hash, "
+                "coin_parent, amount, timestamp FROM coin_record WHERE confirmed_index>?",
+                (block_index,),
+            ) as cursor:
+                for row in await cursor.fetchall():
+                    coin = self.row_to_coin(row)
+                    record = CoinRecord(coin, row[0], uint32(0), row[2], row[6])
+                    if record.name not in coin_changes:
+                        coin_changes[record.name] = record
+
+            if self.db_wrapper.db_version == 2:
+                await conn.execute("UPDATE coin_record SET spent_index=0 WHERE spent_index>?", (block_index,))
+            else:
+                await conn.execute(
+                    "UPDATE coin_record SET spent_index = 0, spent = 0 WHERE spent_index>?", (block_index,)
+                )
         return list(coin_changes.values())
 
     # Store CoinRecord in DB and ram cache
@@ -468,10 +480,12 @@ class CoinStore:
                         record.timestamp,
                     )
                 )
-            await self.coin_record_db.executemany(
-                "INSERT INTO coin_record VALUES(?, ?, ?, ?, ?, ?, ?, ?)",
-                values2,
-            )
+            if len(values2) > 0:
+                async with self.db_wrapper.write_db() as conn:
+                    await conn.executemany(
+                        "INSERT INTO coin_record VALUES(?, ?, ?, ?, ?, ?, ?, ?)",
+                        values2,
+                    )
         else:
             values = []
             for record in records:
@@ -489,10 +503,12 @@ class CoinStore:
                         record.timestamp,
                     )
                 )
-            await self.coin_record_db.executemany(
-                "INSERT INTO coin_record VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?)",
-                values,
-            )
+            if len(values) > 0:
+                async with self.db_wrapper.write_db() as conn:
+                    await conn.executemany(
+                        "INSERT INTO coin_record VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?)",
+                        values,
+                    )
 
     # Update coin_record to be spent in DB
     async def _set_spent(self, coin_names: List[bytes32], index: uint32):
@@ -503,16 +519,27 @@ class CoinStore:
         for coin_name in coin_names:
             r = self.coin_record_cache.get(coin_name)
             if r is not None:
+                if r.spent_block_index != uint32(0):
+                    raise ValueError(f"Coin already spent in cache: {coin_name}")
+
                 self.coin_record_cache.put(
                     r.name, CoinRecord(r.coin, r.confirmed_block_index, index, r.coinbase, r.timestamp)
                 )
             updates.append((index, self.maybe_to_hex(coin_name)))
 
-        if self.db_wrapper.db_version == 2:
-            await self.coin_record_db.executemany(
-                "UPDATE OR FAIL coin_record SET spent_index=? WHERE coin_name=?", updates
-            )
-        else:
-            await self.coin_record_db.executemany(
-                "UPDATE OR FAIL coin_record SET spent=1,spent_index=? WHERE coin_name=?", updates
-            )
+        assert len(updates) == len(coin_names)
+        async with self.db_wrapper.write_db() as conn:
+            if self.db_wrapper.db_version == 2:
+                ret: Cursor = await conn.executemany(
+                    "UPDATE OR FAIL coin_record SET spent_index=? WHERE coin_name=? AND spent_index=0", updates
+                )
+
+            else:
+                ret = await conn.executemany(
+                    "UPDATE OR FAIL coin_record SET spent=1,spent_index=? WHERE coin_name=? AND spent_index=0",
+                    updates,
+                )
+            if ret.rowcount != len(coin_names):
+                raise ValueError(
+                    f"Invalid operation to set spent, total updates {ret.rowcount} expected {len(coin_names)}"
+                )
