@@ -180,7 +180,7 @@ def plot_madmax(args, chia_root_path: Path, plotters_root_path: Path):
         except Exception as e:
             print(f"Exception while installing madmax plotter: {e}")
             return
-    plot_keys = asyncio.get_event_loop().run_until_complete(
+    plot_keys = asyncio.run(
         resolve_plot_keys(
             None if args.farmerkey == b"" else args.farmerkey.hex(),
             None,
@@ -227,8 +227,7 @@ def plot_madmax(args, chia_root_path: Path, plotters_root_path: Path):
         call_args.append("-k")
         call_args.append(str(args.size))
     try:
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(run_plotter(call_args, progress))
+        asyncio.run(run_plotter(call_args, progress))
     except Exception as e:
         print(f"Exception while plotting: {type(e)} {e}")
         print(f"Traceback: {traceback.format_exc()}")
