@@ -1,11 +1,9 @@
 # flake8: noqa: F811, F401
 
-import asyncio
+import logging
 import time
 
 import pytest
-import pytest_asyncio
-import logging
 
 from chia.protocols import full_node_protocol
 from chia.types.peer_info import PeerInfo
@@ -13,7 +11,6 @@ from chia.util.ints import uint16
 from chia.wallet.transaction_record import TransactionRecord
 from chia.wallet.wallet_node import WalletNode
 from tests.connection_utils import connect_and_get_peer
-from tests.setup_nodes import setup_simulators_and_wallets
 from tests.time_out_assert import time_out_assert
 
 
@@ -35,18 +32,12 @@ async def wallet_balance_at_least(wallet_node: WalletNode, balance):
 log = logging.getLogger(__name__)
 
 
-@pytest_asyncio.fixture(scope="module")
-async def wallet_nodes(bt):
-    key_seed = bt.farmer_master_sk_entropy
-    async for _ in setup_simulators_and_wallets(2, 1, {}, key_seed=key_seed):
-        yield _
-
-
 class TestMempoolPerformance:
     @pytest.mark.asyncio
-    async def test_mempool_update_performance(self, bt, wallet_nodes, default_400_blocks, self_hostname):
+    @pytest.mark.benchmark
+    async def test_mempool_update_performance(self, bt, wallet_nodes_mempool_perf, default_400_blocks, self_hostname):
         blocks = default_400_blocks
-        full_nodes, wallets = wallet_nodes
+        full_nodes, wallets = wallet_nodes_mempool_perf
         wallet_node = wallets[0][0]
         wallet_server = wallets[0][1]
         full_node_api_1 = full_nodes[0]
@@ -78,7 +69,12 @@ class TestMempoolPerformance:
         blocks = bt.get_consecutive_blocks(3, blocks)
         await full_node_api_1.full_node.respond_block(full_node_protocol.RespondBlock(blocks[-3]))
 
-        for block in blocks[-2:]:
+        for idx, block in enumerate(blocks):
             start_t_2 = time.time()
             await full_node_api_1.full_node.respond_block(full_node_protocol.RespondBlock(block))
-            assert time.time() - start_t_2 < 1
+            end_t_2 = time.time()
+            duration = end_t_2 - start_t_2
+            if idx >= len(blocks) - 3:
+                assert duration < 0.1
+            else:
+                assert duration < 0.001
