@@ -18,7 +18,7 @@ from chia.plotting.util import add_plot_directory, remove_plot_directory
 from chia.protocols.harvester_protocol import Plot
 from chia.server.start_service import Service
 from chia.types.blockchain_format.sized_bytes import bytes32
-from chia.util.config import create_default_chia_config
+from chia.util.config import create_default_chia_config, lock_and_load_config, save_config
 from chia.util.ints import uint8, uint64
 from tests.block_tools import BlockTools
 from tests.plot_sync.util import start_harvester_service
@@ -30,8 +30,8 @@ from tests.time_out_assert import time_out_assert
 def synced(sender: Sender, receiver: Receiver, previous_last_sync_id: int) -> bool:
     return (
         sender._last_sync_id != previous_last_sync_id
-        and sender._last_sync_id == receiver._last_sync_id != 0
-        and receiver.state() == State.idle
+        and sender._last_sync_id == receiver._last_sync.sync_id != 0
+        and receiver.current_sync().state == State.idle
         and not sender._lock.locked()
     )
 
@@ -211,7 +211,7 @@ class Environment:
             # Make sure to reset the passed flag always before a new run
             self.expected[self.harvesters.index(harvester)].callback_passed = False
             receiver._update_callback = self.plot_sync_callback
-            assert harvester.plot_sync_sender._last_sync_id == receiver._last_sync_id
+            assert harvester.plot_sync_sender._last_sync_id == receiver._last_sync.sync_id
             last_sync_ids.append(harvester.plot_sync_sender._last_sync_id)
             plot_manager.start_refreshing()
             plot_manager.trigger_refresh()
@@ -293,6 +293,10 @@ async def environment(
     farmer: Farmer = farmer_service._node
     harvesters: List[Harvester] = [await start_harvester_service(service) for service in harvester_services]
     for harvester in harvesters:
+        # Remove default plot directory for this tests
+        with lock_and_load_config(harvester.root_path, "config.yaml") as config:
+            config["harvester"]["plot_directories"] = []
+            save_config(harvester.root_path, "config.yaml", config)
         harvester.plot_manager.set_public_keys(
             bt.plot_manager.farmer_public_keys.copy(), bt.plot_manager.pool_public_keys.copy()
         )
