@@ -5,11 +5,9 @@ from typing import AsyncIterator, Dict, List, Tuple
 from pathlib import Path
 
 from chia.consensus.constants import ConsensusConstants
-from chia.cmds.init_funcs import init
 from chia.full_node.full_node_api import FullNodeAPI
 from chia.server.start_service import Service
 from chia.server.start_wallet import service_kwargs_for_wallet
-from chia.util.config import load_config, save_config
 from chia.util.hash import std_hash
 from chia.util.ints import uint16, uint32
 from chia.util.keychain import bytes_to_mnemonic
@@ -290,14 +288,17 @@ async def setup_simulators_and_wallets(
         await _teardown_nodes(node_iters)
 
 
-async def setup_harvester_farmer(bt: BlockTools, consensus_constants: ConsensusConstants, *, start_services: bool):
+async def setup_harvester_farmer(
+    bt: BlockTools, tmp_path: Path, consensus_constants: ConsensusConstants, *, start_services: bool
+):
     farmer_port = find_available_listen_port("farmer")
     farmer_rpc_port = find_available_listen_port("farmer rpc")
     harvester_port = find_available_listen_port("harvester")
     harvester_rpc_port = find_available_listen_port("harvester rpc")
     node_iters = [
         setup_harvester(
-            bt.root_path,
+            bt,
+            tmp_path / "harvester",
             bt.config["self_hostname"],
             harvester_port,
             harvester_rpc_port,
@@ -307,6 +308,7 @@ async def setup_harvester_farmer(bt: BlockTools, consensus_constants: ConsensusC
         ),
         setup_farmer(
             bt,
+            tmp_path / "farmer",
             bt.config["self_hostname"],
             farmer_port,
             farmer_rpc_port,
@@ -334,23 +336,22 @@ async def setup_farmer_multi_harvester(
 
     node_iterators = [
         setup_farmer(
-            block_tools, block_tools.config["self_hostname"], farmer_port, farmer_rpc_port, consensus_constants
+            block_tools,
+            temp_dir / "farmer",
+            block_tools.config["self_hostname"],
+            farmer_port,
+            farmer_rpc_port,
+            consensus_constants,
         )
     ]
 
     for i in range(0, harvester_count):
-        root_path: Path = temp_dir / str(i)
-        init(None, root_path)
-        init(block_tools.root_path / "config" / "ssl" / "ca", root_path)
-        config = load_config(root_path, "config.yaml")
-        config["logging"]["log_stdout"] = True
-        config["selected_network"] = "testnet0"
-        config["harvester"]["selected_network"] = "testnet0"
+        root_path: Path = temp_dir / f"harvester_{i}"
         harvester_port = find_available_listen_port("harvester")
         harvester_rpc_port = find_available_listen_port("harvester rpc")
-        save_config(root_path, "config.yaml", config)
         node_iterators.append(
             setup_harvester(
+                block_tools,
                 root_path,
                 block_tools.config["self_hostname"],
                 harvester_port,
@@ -412,7 +413,8 @@ async def setup_full_system(
         node_iters = [
             setup_introducer(shared_b_tools, introducer_port),
             setup_harvester(
-                shared_b_tools.root_path,
+                shared_b_tools,
+                shared_b_tools.root_path / "harvester",
                 shared_b_tools.config["self_hostname"],
                 harvester_port,
                 harvester_rpc_port,
@@ -421,6 +423,7 @@ async def setup_full_system(
             ),
             setup_farmer(
                 shared_b_tools,
+                shared_b_tools.root_path / "harvester",
                 shared_b_tools.config["self_hostname"],
                 farmer_port,
                 farmer_rpc_port,
