@@ -1,13 +1,13 @@
 from typing import Dict, List, Optional, Tuple, Any
 
-from blspy import AugSchemeMPL, G2Element, PrivateKey
+from blspy import AugSchemeMPL, G2Element, PrivateKey, G1Element
 from clvm.casts import int_from_bytes, int_to_bytes
 
 from chia.consensus.constants import ConsensusConstants
 from chia.util.hash import std_hash
 from chia.types.announcement import Announcement
 from chia.types.blockchain_format.coin import Coin
-from chia.types.blockchain_format.program import Program
+from chia.types.blockchain_format.program import Program, SerializedProgram
 from chia.types.blockchain_format.sized_bytes import bytes32
 from chia.types.coin_spend import CoinSpend
 from chia.types.condition_opcodes import ConditionOpcode
@@ -30,6 +30,7 @@ assert len(DEFAULT_SEED) == 32
 class WalletTool:
     next_address = 0
     pubkey_num_lookup: Dict[bytes, uint32] = {}
+    puzzle_pk_cache: Dict[bytes32, PrivateKey] = {}
 
     def __init__(self, constants: ConsensusConstants, sk: Optional[PrivateKey] = None):
         self.constants = constants
@@ -48,36 +49,32 @@ class WalletTool:
         return self.next_address
 
     def get_private_key_for_puzzle_hash(self, puzzle_hash: bytes32) -> PrivateKey:
-        if puzzle_hash in self.puzzle_pk_cache:
-            child = self.puzzle_pk_cache[puzzle_hash]
-            private = master_sk_to_wallet_sk(self.private_key, uint32(child))
-            #  pubkey = private.get_g1()
-            return private
-        else:
-            for child in range(self.next_address):
-                pubkey = master_sk_to_wallet_sk(self.private_key, uint32(child)).get_g1()
-                if puzzle_hash == puzzle_for_pk(bytes(pubkey)).get_tree_hash():
-                    return master_sk_to_wallet_sk(self.private_key, uint32(child))
+        sk = self.puzzle_pk_cache.get(puzzle_hash)
+        if sk:
+            return sk
+        for child in range(self.next_address):
+            pubkey = master_sk_to_wallet_sk(self.private_key, uint32(child)).get_g1()
+            if puzzle_hash == puzzle_for_pk(bytes(pubkey)).get_tree_hash():
+                return master_sk_to_wallet_sk(self.private_key, uint32(child))
         raise ValueError(f"Do not have the keys for puzzle hash {puzzle_hash}")
 
     def puzzle_for_pk(self, pubkey: bytes) -> Program:
         return puzzle_for_pk(pubkey)
 
-    def get_new_puzzle(self) -> bytes32:
+    def get_new_puzzle(self) -> Program:
         next_address_index: uint32 = self.get_next_address_index()
-        pubkey = master_sk_to_wallet_sk(self.private_key, next_address_index).get_g1()
+        sk: PrivateKey = master_sk_to_wallet_sk(self.private_key, next_address_index)
+        pubkey: G1Element = sk.get_g1()
         self.pubkey_num_lookup[bytes(pubkey)] = next_address_index
 
-        puzzle = puzzle_for_pk(bytes(pubkey))
+        puzzle: Program = puzzle_for_pk(pubkey)
 
-        self.puzzle_pk_cache[puzzle.get_tree_hash()] = next_address_index
+        self.puzzle_pk_cache[puzzle.get_tree_hash()] = sk
         return puzzle
 
     def get_new_puzzlehash(self) -> bytes32:
         puzzle = self.get_new_puzzle()
-        # TODO: address hint error and remove ignore
-        #       error: "bytes32" has no attribute "get_tree_hash"  [attr-defined]
-        return puzzle.get_tree_hash()  # type: ignore[attr-defined]
+        return puzzle.get_tree_hash()
 
     def sign(self, value: bytes, pubkey: bytes) -> G2Element:
         privatekey: PrivateKey = master_sk_to_wallet_sk(self.private_key, self.pubkey_num_lookup[pubkey])
@@ -106,6 +103,7 @@ class WalletTool:
         fee: int = 0,
         secret_key: Optional[PrivateKey] = None,
         additional_outputs: Optional[List[Tuple[bytes32, int]]] = None,
+        memo: Optional[bytes32] = None,
     ) -> List[CoinSpend]:
         spends = []
 
@@ -116,7 +114,10 @@ class WalletTool:
         if ConditionOpcode.CREATE_COIN_ANNOUNCEMENT not in condition_dic:
             condition_dic[ConditionOpcode.CREATE_COIN_ANNOUNCEMENT] = []
 
-        output = ConditionWithArgs(ConditionOpcode.CREATE_COIN, [new_puzzle_hash, int_to_bytes(amount)])
+        coin_create = [new_puzzle_hash, int_to_bytes(amount)]
+        if memo is not None:
+            coin_create.append(memo)
+        output = ConditionWithArgs(ConditionOpcode.CREATE_COIN, coin_create)
         condition_dic[output.opcode].append(output)
         if additional_outputs is not None:
             for o in additional_outputs:
@@ -137,15 +138,13 @@ class WalletTool:
             if secret_key is None:
                 secret_key = self.get_private_key_for_puzzle_hash(puzzle_hash)
             pubkey = secret_key.get_g1()
-            puzzle = puzzle_for_pk(bytes(pubkey))
+            puzzle: Program = puzzle_for_pk(pubkey)
             if n == 0:
                 message_list = [c.name() for c in coins]
                 for outputs in condition_dic[ConditionOpcode.CREATE_COIN]:
-                    # TODO: address hint error and remove ignore
-                    #       error: Argument 2 to "Coin" has incompatible type "bytes"; expected "bytes32"  [arg-type]
                     coin_to_append = Coin(
                         coin.name(),
-                        outputs.vars[0],  # type: ignore[arg-type]
+                        bytes32(outputs.vars[0]),
                         int_from_bytes(outputs.vars[1]),
                     )
                     message_list.append(coin_to_append.name())
@@ -158,9 +157,19 @@ class WalletTool:
                     ConditionWithArgs(ConditionOpcode.ASSERT_COIN_ANNOUNCEMENT, [primary_announcement_hash])
                 )
                 main_solution = self.make_solution(condition_dic)
-                spends.append(CoinSpend(coin, puzzle, main_solution))
+                spends.append(
+                    CoinSpend(
+                        coin, SerializedProgram.from_program(puzzle), SerializedProgram.from_program(main_solution)
+                    )
+                )
             else:
-                spends.append(CoinSpend(coin, puzzle, self.make_solution(secondary_coins_cond_dic)))
+                spends.append(
+                    CoinSpend(
+                        coin,
+                        SerializedProgram.from_program(puzzle),
+                        SerializedProgram.from_program(self.make_solution(secondary_coins_cond_dic)),
+                    )
+                )
         return spends
 
     def sign_transaction(self, coin_spends: List[CoinSpend]) -> SpendBundle:
@@ -199,11 +208,12 @@ class WalletTool:
         condition_dic: Dict[ConditionOpcode, List[ConditionWithArgs]] = None,
         fee: int = 0,
         additional_outputs: Optional[List[Tuple[bytes32, int]]] = None,
+        memo: Optional[bytes32] = None,
     ) -> SpendBundle:
         if condition_dic is None:
             condition_dic = {}
         transaction = self.generate_unsigned_transaction(
-            amount, new_puzzle_hash, [coin], condition_dic, fee, additional_outputs=additional_outputs
+            amount, new_puzzle_hash, [coin], condition_dic, fee, additional_outputs=additional_outputs, memo=memo
         )
         assert transaction is not None
         return self.sign_transaction(transaction)
